Index: /trunk/gsdl3/src/java/org/greenstone/gsdl3/action/AppletAction.java
===================================================================
--- /trunk/gsdl3/src/java/org/greenstone/gsdl3/action/AppletAction.java	(revision 4143)
+++ /trunk/gsdl3/src/java/org/greenstone/gsdl3/action/AppletAction.java	(revision 4144)
@@ -77,8 +77,6 @@
 	Element page = doc_.createElement(GSXML.PAGE_ELEM);
 	page.setAttribute(GSXML.LANG_ATT, lang);
-	// add the lang stuff from message
-	page.appendChild(doc_.importNode(GSXML.getChildByTagName(message, GSXML.DISPLAY_ELEM), true));
-	// add the config stuff from message
-	page.appendChild(doc_.importNode(GSXML.getChildByTagName(message, GSXML.CONFIGURATION_ELEM), true));
+	// add the page extra stuff from message
+	page.appendChild(doc_.importNode(GSXML.getChildByTagName(message, GSXML.PAGE_EXTRA_ELEM), true));
 
 	// add in the page Request
Index: /trunk/gsdl3/src/java/org/greenstone/gsdl3/action/BrowseAction.java
===================================================================
--- /trunk/gsdl3/src/java/org/greenstone/gsdl3/action/BrowseAction.java	(revision 4143)
+++ /trunk/gsdl3/src/java/org/greenstone/gsdl3/action/BrowseAction.java	(revision 4144)
@@ -33,8 +33,6 @@
 	Element page = doc_.createElement(GSXML.PAGE_ELEM);
 	page.setAttribute(GSXML.LANG_ATT, request.getAttribute(GSXML.LANG_ATT));
-	// add the lang stuff from message
-	page.appendChild(doc_.importNode(GSXML.getChildByTagName(message, GSXML.DISPLAY_ELEM), true));
-	// add the system stuff from message
-	page.appendChild(doc_.importNode(GSXML.getChildByTagName(message, GSXML.CONFIGURATION_ELEM), true));
+	// add the page extra stuff from message
+	page.appendChild(doc_.importNode(GSXML.getChildByTagName(message, GSXML.PAGE_EXTRA_ELEM), true));
 
 	return classifierBrowse(page, request);
Index: /trunk/gsdl3/src/java/org/greenstone/gsdl3/action/DocumentAction.java
===================================================================
--- /trunk/gsdl3/src/java/org/greenstone/gsdl3/action/DocumentAction.java	(revision 4143)
+++ /trunk/gsdl3/src/java/org/greenstone/gsdl3/action/DocumentAction.java	(revision 4144)
@@ -87,7 +87,6 @@
 	page.setAttribute(GSXML.LANG_ATT, lang);
 
-	// Add the display element, config stuff, and original request from the message
-	page.appendChild(doc_.importNode(GSXML.getChildByTagName(message, GSXML.DISPLAY_ELEM), true));
-	page.appendChild(doc_.importNode(GSXML.getChildByTagName(message, GSXML.CONFIGURATION_ELEM), true));
+	// Add the page extra element,  and original request from the message
+	page.appendChild(doc_.importNode(GSXML.getChildByTagName(message, GSXML.PAGE_EXTRA_ELEM), true));
 	Element page_request = GSXML.duplicateWithNewName(doc_, request, GSXML.PAGE_REQUEST_ELEM, true);
 	page.appendChild(page_request);
Index: /trunk/gsdl3/src/java/org/greenstone/gsdl3/action/PageAction.java
===================================================================
--- /trunk/gsdl3/src/java/org/greenstone/gsdl3/action/PageAction.java	(revision 4143)
+++ /trunk/gsdl3/src/java/org/greenstone/gsdl3/action/PageAction.java	(revision 4144)
@@ -30,8 +30,6 @@
 	Element page = doc_.createElement(GSXML.PAGE_ELEM);
 	page.setAttribute(GSXML.LANG_ATT, request.getAttribute(GSXML.LANG_ATT));
-	// add the lang stuff from message
-	page.appendChild(doc_.importNode(GSXML.getChildByTagName(message, GSXML.DISPLAY_ELEM), true));
-	// add the system stuff from message
-	page.appendChild(doc_.importNode(GSXML.getChildByTagName(message, GSXML.CONFIGURATION_ELEM), true));
+	// add the page extra stuff from message
+	page.appendChild(doc_.importNode(GSXML.getChildByTagName(message, GSXML.PAGE_EXTRA_ELEM), true));
 	// add the cgi args request
 	Element page_request = GSXML.duplicateWithNewName(doc_, request, "pageRequest", true);
Index: /trunk/gsdl3/src/java/org/greenstone/gsdl3/action/ProcessAction.java
===================================================================
--- /trunk/gsdl3/src/java/org/greenstone/gsdl3/action/ProcessAction.java	(revision 4143)
+++ /trunk/gsdl3/src/java/org/greenstone/gsdl3/action/ProcessAction.java	(revision 4144)
@@ -107,9 +107,6 @@
 	}
 	
-	// add the lang stuff from message
-	page.appendChild(doc_.importNode(GSXML.getChildByTagName(message, GSXML.DISPLAY_ELEM), true));
-	// add the system stuff from message
-	page.appendChild(doc_.importNode(GSXML.getChildByTagName(message, GSXML.CONFIGURATION_ELEM), true));
-	
+	// add the page extra stuff from message
+	page.appendChild(doc_.importNode(GSXML.getChildByTagName(message, GSXML.PAGE_EXTRA_ELEM), true));
 
 	// another part of the page is the service description
Index: /trunk/gsdl3/src/java/org/greenstone/gsdl3/action/QueryAction.java
===================================================================
--- /trunk/gsdl3/src/java/org/greenstone/gsdl3/action/QueryAction.java	(revision 4143)
+++ /trunk/gsdl3/src/java/org/greenstone/gsdl3/action/QueryAction.java	(revision 4144)
@@ -29,8 +29,6 @@
 	Element page = doc_.createElement(GSXML.PAGE_ELEM);
 	page.setAttribute(GSXML.LANG_ATT, request.getAttribute(GSXML.LANG_ATT));
-	// add the lang stuff from message
-	page.appendChild(doc_.importNode(GSXML.getChildByTagName(message, GSXML.DISPLAY_ELEM), true));
-	// add the system stuff from message
-       page.appendChild(doc_.importNode(GSXML.getChildByTagName(message, GSXML.CONFIGURATION_ELEM), true));
+	// add the page extra stuff from message
+	page.appendChild(doc_.importNode(GSXML.getChildByTagName(message, GSXML.PAGE_EXTRA_ELEM), true));
 
 	// part of the data for the page is the cgi-params
@@ -77,5 +75,5 @@
 	String to = GSPath.appendLink(collection, service_name);
 
-	//create teh pageREsponse
+	//create the pageResponse
 	Element page_response = doc_.createElement(GSXML.PAGE_RESPONSE_ELEM);
 	page.appendChild(page_response);
Index: /trunk/gsdl3/src/java/org/greenstone/gsdl3/action/SystemAction.java
===================================================================
--- /trunk/gsdl3/src/java/org/greenstone/gsdl3/action/SystemAction.java	(revision 4143)
+++ /trunk/gsdl3/src/java/org/greenstone/gsdl3/action/SystemAction.java	(revision 4144)
@@ -30,8 +30,6 @@
 	page.setAttribute(GSXML.LANG_ATT, lang);
 
-	// add the lang stuff from message
-	page.appendChild(doc_.importNode(GSXML.getChildByTagName(message, GSXML.DISPLAY_ELEM), true));
-	// add the system stuff from message
-	page.appendChild(doc_.importNode(GSXML.getChildByTagName(message, GSXML.CONFIGURATION_ELEM), true));
+	// add the page extra stuff from message
+	page.appendChild(doc_.importNode(GSXML.getChildByTagName(message, GSXML.PAGE_EXTRA_ELEM), true));
 
 	String coll = (String)params.get(GSCGI.COLLECTION_ARG);
Index: /trunk/gsdl3/src/java/org/greenstone/gsdl3/core/Receptionist.java
===================================================================
--- /trunk/gsdl3/src/java/org/greenstone/gsdl3/core/Receptionist.java	(revision 4143)
+++ /trunk/gsdl3/src/java/org/greenstone/gsdl3/core/Receptionist.java	(revision 4144)
@@ -189,10 +189,13 @@
 	}
 
 	// add in the  system stuff - display and config
 	Document message_doc = message.getOwnerDocument();
+	Element page_extra = message_doc.createElement(GSXML.PAGE_EXTRA_ELEM);
+	message.appendChild(page_extra);
 	String lang = request.getAttribute(GSXML.LANG_ATT);
 	Element display = getDisplayElement(lang);
-	message.appendChild(message_doc.importNode(display, true));
-	message.appendChild(message_doc.importNode(config_.config_xml_, true));
+	page_extra.appendChild(message_doc.importNode(display, true));
+	page_extra.appendChild(message_doc.importNode(config_.config_xml_, true));
 
 	Element page = a.process(message);
@@ -189,10 +189,13 @@
 	}
 
-	// add in the  system stuff - display and config
+	// add in the  system stuff - display and config - this all goes into 
+	// a pageExtra element
 	Document message_doc = message.getOwnerDocument();
